<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk_SK">
<context>
    <name>Clipboard</name>
    <message>
        <location filename="../src/clipboard.cpp" line="79"/>
        <source>Copy color %1 to clipboard</source>
        <translation>Kopírovať farbu %1 do schránky</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main.cpp" line="58"/>
        <source>Deepin Picker is a quick and easy screen color picking tool. RGB and HEX codes are obtained on click and auto saved to the clipboard.</source>
        <translation>Deepin Výber je nástroj rýchleho vyberania farieb na obrazovke. RGB a HEX kód je možné získať podľa vybratej farby a automaticky uloženej do schránky. Oblasť výberu farieb je miesto, kde kliknete myšou.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="80"/>
        <source>Deepin Picker</source>
        <translation>Deepin Výber</translation>
    </message>
</context>
</TS>
